@@ -31,6 +31,7 @@ class InvalidTag(Exception):
     pass
 
 
+@lru_cache()
 def read_json(path: str):
     fullpath = os.path.join(os.path.dirname(os.path.abspath(__file__)), "Data/" + path)
     with open(fullpath, "rb") as myfile:
@@ -81,10 +82,7 @@ class CaseInsensitiveSet(collections.abc.Set):
         return self._elements.__repr__()
 
     def issubset(self, other):
-        for value in self:
-            if value not in other:
-                return False
-        return True
+        return all(value in other for value in self)
 
 
 class Keys(Enum):
