@@ -1,6 +1,5 @@
 import json
 import os
-from functools import lru_cache
 
 from rich.console import Console
 from rich.table import Table
@@ -14,7 +13,7 @@ class Printing:
     def pretty_print(self, text: dict, text_input):
         to_out = ""
 
-        if text["File Signatures"] and text["Regexes"]:
+        if text["File Signatures"]:
             for key, value in text["File Signatures"].items():
                 if value:
                     to_out += "\n"
@@ -34,7 +33,7 @@ class Printing:
             if self._check_if_directory(text_input):
                 # if input is a folder, add a filename column
                 table.add_column("File", overflow="fold")
-            
+
             # Check if there are any bug bounties with exploits
             # in the regex
             self._check_if_exploit_in_json(text)
@@ -63,14 +62,17 @@ class Printing:
                             )
                         else:
                             description = i["Regex Pattern"]["Description"]
-                    
-                    if "Exploit" in i["Regex Pattern"] and i["Regex Pattern"]["Exploit"]:
+
+                    if (
+                        "Exploit" in i["Regex Pattern"]
+                        and i["Regex Pattern"]["Exploit"]
+                    ):
                         exploit = i["Regex Pattern"]["Exploit"]
 
                     if not description:
                         description = "None"
 
-                    #FIXME this is quite messy
+                    # FIXME this is quite messy
                     if self.bug_bounty_mode:
                         if self._check_if_directory(text_input):
                             table.add_row(
@@ -87,33 +89,33 @@ class Printing:
                                 description,
                                 exploit,
                             )
+                    elif self._check_if_directory(text_input):
+                        table.add_row(
+                            matched,
+                            name,
+                            description,
+                            filename,
+                        )
                     else:
-                        if self._check_if_directory(text_input):
-                            table.add_row(
-                                matched,
-                                name,
-                                description,
-                                filename,
-                            )
-                        else:
-                            table.add_row(
-                                matched,
-                                name,
-                                description,
-                            )
+                        table.add_row(
+                            matched,
+                            name,
+                            description,
+                        )
 
-            self.console.print(to_out, table)
+            self.console.print(to_out.strip(), table)
 
-        if to_out == "":
-            self.console.print("Nothing found!")
+        elif not self.bug_bounty_mode:
+            self.console.print((to_out + "\nNothing found!").lstrip())
 
     def print_json(self, text: dict):
         self.console.print(json.dumps(text))
-    
+
     """
     Does not create a table, prints it as raw text
     Returns the printable object
     """
+
     def print_raw(self, text: dict, text_input) -> str:
         output_str = ""
 
@@ -124,7 +126,6 @@ class Printing:
                     output_str += f"[bold #D7Afff]File Identified[/bold #D7Afff]: [bold]{key}[/bold] with Magic Numbers {value['ISO 8859-1']}."
                     output_str += f"\n[bold #D7Afff]File Description:[/bold #D7Afff] {value['Description']}."
                     output_str += "\n"
-        
 
         if text["Regexes"]:
             for key, value in text["Regexes"].items():
@@ -133,8 +134,13 @@ class Printing:
                     matched = i["Matched"]
                     if self._check_if_directory(text_input):
                         output_str += f"[bold #D7Afff]File: {key}[/bold #D7Afff]\n"
-                    output_str += "[bold #D7Afff]Matched on: [/bold #D7Afff]" + i["Matched"]
-                    output_str += "\n[bold #D7Afff]Name: [/bold #D7Afff]" + i["Regex Pattern"]["Name"]
+                    output_str += (
+                        "[bold #D7Afff]Matched on: [/bold #D7Afff]" + i["Matched"]
+                    )
+                    output_str += (
+                        "\n[bold #D7Afff]Name: [/bold #D7Afff]"
+                        + i["Regex Pattern"]["Name"]
+                    )
 
                     link = None
                     if "URL" in i["Regex Pattern"] and i["Regex Pattern"]["URL"]:
@@ -143,27 +149,37 @@ class Printing:
                             + i["Regex Pattern"]["URL"]
                             + matched.replace(" ", "")
                         )
-                    
+
                     if link:
                         output_str += link
 
                     if i["Regex Pattern"]["Description"]:
-                         description = "\n[bold #D7Afff]Description: [/bold #D7Afff]" + i["Regex Pattern"]["Description"]
-                    
+                        description = (
+                            "\n[bold #D7Afff]Description: [/bold #D7Afff]"
+                            + i["Regex Pattern"]["Description"]
+                        )
+
                     if description:
                         output_str += description
-                    
-                    if "Exploit" in i["Regex Pattern"] and i["Regex Pattern"]["Exploit"]:
-                        output_str += "\n[bold #D7Afff]Exploit: [/bold #D7Afff]" + i["Regex Pattern"]["Exploit"]
+
+                    if (
+                        "Exploit" in i["Regex Pattern"]
+                        and i["Regex Pattern"]["Exploit"]
+                    ):
+                        output_str += (
+                            "\n[bold #D7Afff]Exploit: [/bold #D7Afff]"
+                            + i["Regex Pattern"]["Exploit"]
+                        )
                     output_str += "\n\n"
 
-        if output_str == "":
+        if output_str == "" and not self.bug_bounty_mode:
             self.console.print("Nothing found!")
 
-        self.console.print(output_str)
-    
+        if output_str.strip():
+            self.console.print(output_str.rstrip())
+
     def _check_if_exploit_in_json(self, text: dict) -> bool:
-        if "File Signatures" in text.keys() and text["File Signatures"]:
+        if "File Signatures" in text and text["File Signatures"]:
             # loops files
             for file in text["Regexes"].keys():
                 for i in text["Regexes"][file]:
@@ -175,4 +191,4 @@ class Printing:
                     self.bug_bounty_mode = True
 
     def _check_if_directory(self, text_input):
-        return os.path.isdir(text_input)
\ No newline at end of file
+        return os.path.isdir(text_input)
